from ..base import SMSProvider


class Twilio(SMSProvider):
    def send_sms(self):
        from twilio.rest import Client

        client = Client(self.conf.SMS_AUTH_ACCOUNT_SID, self.conf.SMS_AUTH_AUTH_TOKEN)
        message = client.messages.create(
            to=f"{self.to}", from_=self.conf.SMS_PROVIDER_FROM, body=self.message
        )

        return message



import setuptools

with open("README.md", "r") as fh:
    long_description = fh.read()

setuptools.setup(
    name="django-rest-sms-auth",
    version="0.1.18",
    author="Andrei Koptev",
    author_email="akoptev1989@ya.ru",
    description="Django users authentication through SMS code",
    license='MIT',
    long_description=long_description,
    long_description_content_type="text/markdown",
    keywords='django rest auth sms registration rest-framework django-registration sms',
    url="https://github.com/a1k89/django-rest-sms-auth",
    packages=setuptools.find_packages(exclude=["demo"]),
    install_requires=['Django>=2.0',
                      'djangorestframework>=3.0',
                      'phonenumbers',
                      'django-phonenumber-field',
                      'celery>=5.0'],
    classifiers=[
        'Framework :: Django',
        'Intended Audience :: Developers',
        'Intended Audience :: System Administrators',
        'Operating System :: OS Independent',
        'Topic :: Software Development'
    ],
    include_package_data=True
)


import random
from abc import ABC, abstractmethod
from datetime import timedelta

from django.db import transaction
from django.utils import timezone


class SmsService(ABC):
    @classmethod
    def execute(cls, **kwargs):
        instance = cls(**kwargs)
        with transaction.atomic():
            return instance.process()

    @abstractmethod
    def process(self):
        pass


def valid_to():
    from .conf import conf

    now = timezone.now()
    delta = conf.SMS_TIMELIFE
    due_at = now + timedelta(seconds=delta)

    return due_at


def random_n(n) -> int:
    range_start = 10 ** (n - 1)
    range_finish = (10 ** n) - 1

    return random.randint(range_start, range_finish)


def random_code() -> int:
    from .conf import conf

    code = random_n(conf.SMS_AUTH_CODE_LEN)

    if conf.SMS_DEBUG:
        code = conf.SMS_DEBUG_CODE

    return code
